"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const util_1 = require("./util");
function search_xiph(search) {
    return new Promise(resolve => {
        const options = {
            method: 'GET',
            url: 'http://dir.xiph.org/search?search=' + search.split(' ').join('+')
        };
        require('request')(options, (err, _, body) => {
            if (err)
                resolve([util_1.error_entry(err, 'Icecast')]);
            else
                resolve(parse_xiph(body));
        });
    });
}
exports.search_xiph = search_xiph;
function parse_xiph(body) {
    const JSDOM = require('jsdom').JSDOM;
    const host = 'http://dir.xiph.org';
    const playing_pos = 25;
    let document;
    try {
        document = new JSDOM(body).window.document;
    }
    catch (err) {
        return [util_1.error_entry('Couldn\'t parse XIPH', 'Icecast')];
    }
    const rows = document
        .querySelector('body > #thepage > #content > .servers-list :nth-child(1)');
    if (rows === null)
        return [];
    else
        return Array.from(rows.children).map((entry) => {
            const sel_name_hp = entry.querySelector('.description > .stream-name > .name > a');
            const sel_listeners = entry.querySelector('.description > .stream-name > .listeners');
            const sel_description = entry.querySelector('.description > .stream-description');
            const sel_playing = entry.querySelector('.description > .stream-onair');
            const sel_url = entry.querySelector('.tune-in > .format ~ p :nth-child(1)');
            const sel_bitrate = entry.querySelector('.tune-in > p ~ :last-child');
            let bitrate;
            if (sel_bitrate && sel_bitrate.title) {
                const match = sel_bitrate.title.match(/\d+/);
                if (sel_bitrate.title.includes('kbps') && match)
                    bitrate = match[0];
                else
                    bitrate = '';
            }
            else {
                bitrate = 'Null';
            }
            return {
                name: sel_name_hp ? sel_name_hp.innerHTML
                    : 'Null',
                homepage: sel_name_hp ? sel_name_hp.href
                    : 'Null',
                listeners: sel_listeners ? sel_listeners.innerHTML.split('&nbsp')[0].substr(1)
                    : 'Null',
                description: sel_description ? sel_description.innerHTML
                    : '',
                playing: sel_playing ? sel_playing.innerHTML.substr(playing_pos)
                    : '',
                url: sel_url ? host + sel_url.href
                    : 'Null',
                bitrate,
                src: 'Icecast',
                is_playlist: true,
                entry: entry.innerHTML
            };
        });
}
